@@ -1,5 +1,7 @@
 
 from __future__ import absolute_import, division, print_function
+
+from collections import OrderedDict
 from json.decoder import JSONDecodeError
 from astropy.table import Table
 from .data_products import NumpyDataProduct, BinaryData, ApiCatalog
@@ -44,6 +46,7 @@ import oda_api.misc_helpers
 import logging
 
 logger = logging.getLogger("oda_api.api")
+advice_logger = logging.getLogger("oda_api.advice")
 
 
 __all__ = ['Request', 'NoTraceBackWithLineNumber',
@@ -100,6 +103,10 @@ class RequestNotUnderstood(Exception):
 class Unauthorized(RemoteException):
     pass
 
+class URLRedirected(Exception):
+    pass
+
+
 exception_by_message = {
     'failed: get dataserver products ': FailedToFindAnyUsefulResults
 }
@@ -165,7 +172,7 @@ class DispatcherAPI:
 
     def __init__(self,
                  instrument='mock',
-                 url="https://www.astro.unige.ch/mmoda/dispatch-data",
+                 url=None,
                  run_analysis_handle='run_analysis',
                  host=None,
                  port=None,
@@ -176,6 +183,9 @@ class DispatcherAPI:
                  session_id=None,
                  ):
 
+        if url is None:
+            url = "https://www.astro.unige.ch/mmoda/dispatch-data"
+
         if host is not None:
             msg = '\n'
             msg += '----------------------------------------------------------------------------\n'
@@ -334,9 +344,11 @@ class DispatcherAPI:
 
             self.last_request_t0 = time.time()
 
+            url = "%s/%s" % (self.url, self.run_analysis_handle)
+
             if self.selected_request_method == 'GET':
                 response = requests.get(
-                    "%s/%s" % (self.url, self.run_analysis_handle),
+                    url,
                     params=self.parameters_dict_payload,
                     cookies=self.cookies,
                     headers={
@@ -344,10 +356,11 @@ class DispatcherAPI:
                         'Connection-Timeout': str(timeout),
                     },
                     timeout=timeout,
+                    allow_redirects=False
                 )
             elif self.selected_request_method == 'POST':
                 response = requests.post(
-                    "%s/%s" % (self.url, self.run_analysis_handle),
+                    url,
                     data=self.parameters_dict_payload,
                     cookies=self.cookies,
                     headers={
@@ -355,10 +368,20 @@ class DispatcherAPI:
                         'Connection-Timeout': str(timeout),
                     },
                     timeout=timeout,
-                )
+                    allow_redirects=False
+                )                
             else:
                 NotImplementedError
 
+            if response.status_code in (301, 302):
+                # we can not automatically redirect with POST due to unexpected behavior of requests module
+                # there is a very strange and mysterious story about this:
+                # * https://github.com/psf/requests/blob/1e5fad7433772b648fcbc921e2a79de5c4c6be8b/requests/sessions.py#L329-L332
+                # * https://github.com/psf/requests/issues/1704
+                # to avoid confusion, we will instruct the user to change the code:
+                raise URLRedirected(f"the service was moved{' permanently' if response.status_code == 301 else ''}, "
+                                    f"please reinitialize DispatcherAPI with \"{response.headers['Location']}\" (you asked for \"{url}\")")
+
             if response.status_code == 403:
                 try:
                     response_json = response.json()                                    
@@ -399,7 +422,14 @@ class DispatcherAPI:
         mismatching_parameters = []
         for k in self.parameters_dict.keys():
             # these do not correspond to meaning
-            if k in ['query_status', 'off_line', 'verbose', 'dry_run']:                
+            ''' 
+            The dry_run parameter is not actually considered within the oda_api,
+            but we keep it here for  consistency.
+            As discussed in: 
+            * https://github.com/oda-hub/oda_api/pull/85
+            * https://github.com/oda-hub/oda_api/issues/84
+            '''
+            if k in ['query_status', 'off_line', 'verbose', 'dry_run']:
                 continue
 
             returned = self.returned_analysis_parameters.get(k, None)
@@ -436,8 +466,8 @@ class DispatcherAPI:
         if self.is_submitted:
              return {
                  **p,
-        #         'job_id': self.job_id,
-        #         'query_status': self.query_status,
+                'job_id': self.job_id,
+                'query_status': self.query_status,
              }
         else:
              return p
@@ -803,13 +833,20 @@ class DispatcherAPI:
                     product: str,
                     instrument: str,
                     verbose=None,
-                    dry_run: bool = False,
                     product_type: str = 'Real',
+                    silent=False,
                     **kwargs):
         """
         submit query, wait (if allowed by self.wait), decode output when found
         """
 
+        if not silent:
+            advice_logger.warning('please beware that by default, in a typical setup, oda_api will not output much. '
+                                'To learn how to increase the verbosity, please refer to the documentation: '
+                                'https://oda-api.readthedocs.io/en/latest/user_guide/ScienceWindowList.html?highlight=logging#Let\'s-get-some-logging . \n'
+                                'To disable this message you can pass `.get_product(..., silent=True)`'
+                                )
+
         self.job_id = None
 
         # TODO: it's confusing when and where these are passed
@@ -823,7 +860,11 @@ class DispatcherAPI:
         kwargs['query_status'] = 'new',
         kwargs['verbose'] = verbose,
         kwargs['session_id'] = self.session_id
-        kwargs['dry_run'] = dry_run,
+
+        if 'dry_run' in kwargs:
+            warnings.warn('The dry_run parameter you included is not going to have any effect on the execution.\n'
+                          'However the oda_api will perform a check of the list of valid parameters for your request.')
+            del kwargs['dry_run']
 
         res = requests.get("%s/api/par-names" % self.url, params=dict(
             instrument=instrument, product_type=product), cookies=self.cookies)
@@ -833,7 +874,7 @@ class DispatcherAPI:
                 'parameter check not available on remote server, check carefully parameters name')
         else:
             _ignore_list = ['instrument', 'product_type', 'query_type',
-                            'off_line', 'query_status', 'verbose', 'session_id', 'dry_run']
+                            'off_line', 'query_status', 'verbose', 'session_id']
             validation_dict = copy.deepcopy(kwargs)
 
             for _i in _ignore_list:
@@ -883,18 +924,8 @@ class DispatcherAPI:
             raise RuntimeError(
                 "not failed, not, but complete? programming error for client!")
 
-        # <
-
-        data = None
-
-        if not dry_run:
-            d = DataCollection.from_response_json(
-                res_json, instrument, product)
-
-        else:
-            self._decode_res_json(
-                res.json()['products']['instrument_parameters'])
-            d = None
+        d = DataCollection.from_response_json(
+            res_json, instrument, product)
 
         del(res)
 
@@ -903,6 +934,8 @@ class DispatcherAPI:
     @staticmethod
     def set_api_code(query_dict, url="www.astro.unige.ch/mmoda/dispatch-data"):
 
+        query_dict = OrderedDict(sorted(query_dict.items()))
+
         _skip_list_ = ['job_id', 'query_status',
                        'session_id', 'use_resolver[local]', 'use_scws']
 
