@@ -6,26 +6,43 @@ import os
 from oda_api import cli
 
 
-@pytest.mark.parametrize('token_placement', ['env', 'homedotfile', 'cwddotfile'])
-def test_token_inspect(token_placement, default_token, monkeypatch, caplog):
+@pytest.mark.parametrize('token_placement', ['no', 'env', 'homedotfile', 'cwddotfile'])
+def test_token_inspect(token_placement, default_token, monkeypatch, caplog, tmpdir):
+    # reset any existing token locations    
+    os.makedirs(tmpdir, exist_ok=True)    
+    monkeypatch.setenv('HOME', tmpdir)
+
+    oda_token_home_fn = os.path.join(tmpdir, ".oda-token")
+    if os.path.exists(oda_token_home_fn):
+        os.remove(oda_token_home_fn)
+
+    oda_token_cwd_fn = ".oda-token"
+    if os.path.exists(oda_token_cwd_fn):
+        os.remove(oda_token_cwd_fn)
+    
+    monkeypatch.setenv('ODA_TOKEN', '')
+
     if token_placement == 'env':
-        monkeypatch.setenv('ODA_TOKEN', default_token)
+        monkeypatch.setenv('ODA_TOKEN', default_token)    
+        
     elif token_placement == 'cwddotfile':
-        with open(".oda-token", "w") as f:
+        with open(oda_token_cwd_fn, "w") as f:
             f.write(default_token)
+
     elif token_placement == 'homedotfile':
-        fakehome = "fake-home"
-        os.makedirs(fakehome, exist_ok=True)
-        monkeypatch.setenv('HOME', fakehome)
-        with open(os.path.join(fakehome, ".oda-token"), "w") as f:
+        with open(oda_token_home_fn, "w") as f:
             f.write(default_token)
 
     runner = CliRunner()
     result = runner.invoke(cli.tokencli, ['inspect'], obj={})
-    assert result.exit_code == 0
-    
-    assert '"sub": "mtm@mtmco.net"' in caplog.text
-    assert '"mssub": true' in caplog.text    
+
+    if token_placement == 'no':
+        assert result.exit_code == 1
+        assert 'failed to discover token with any known method' in caplog.text
+    else:
+        assert result.exit_code == 0
+        assert '"sub": "mtm@mtmco.net"' in caplog.text
+        assert '"mssub": true' in caplog.text    
 
 def test_token_modify(default_token, secret_key, monkeypatch, caplog):
     monkeypatch.setenv('ODA_TOKEN', default_token)
@@ -52,7 +69,9 @@ def test_get(dispatcher_live_fixture, caplog):
     runner = CliRunner()
     result = runner.invoke(cli.cli, ['-u', dispatcher_live_fixture, 'get'], obj={})
     assert result.exit_code == 0
-    assert "found instruments: ['empty', 'empty-async', 'empty-semi-async']" in caplog.text
+
+    assert "found instruments: ['empty', 'empty-async', 'empty-semi-async']" in caplog.text or \
+           "found instruments: ['empty', 'empty-async', 'empty-semi-async', 'isgri', 'jemx', 'osa_fake']" in caplog.text
 
     runner = CliRunner()
     result = runner.invoke(cli.cli, ['-u', dispatcher_live_fixture, 'get', '-i', 'empty'], obj={})
